@@ -15,13 +15,13 @@
 module Google
   module Apis
     # Client library version
-    VERSION = '0.19.8'
+    VERSION = '0.23.4'
 
     # Current operating system
     # @private
     OS_VERSION = begin
       if RUBY_PLATFORM =~ /mswin|win32|mingw|bccwin|cygwin/
-        `ver`.sub(/\s*\[Version\s*/, '/').sub(']', '').strip
+        `ver`.sub(/\s*\[Version\s*/, '/').sub(']', '')
       elsif RUBY_PLATFORM =~ /darwin/i
         "Mac OS X/#{`sw_vers -productVersion`}"
       elsif RUBY_PLATFORM == 'java'
@@ -31,7 +31,7 @@ module Google
         "#{name}/#{version}"
       else
         `uname -sr`.sub(' ', '/')
-      end
+      end.strip
     rescue
       RUBY_PLATFORM
     end
